@@ -3,7 +3,7 @@
 #' Apply change point test by \insertCite{Horvath_etal_2017;textual}{funtimes} 
 #' for detecting at-most-\eqn{m} changes in regression coefficients, where
 #' test statistic is a modified cumulative sum (CUSUM), and 
-#' critical values are obtained with sieve bootstrap.
+#' critical values are obtained with sieve bootstrap \insertCite{Lyubchich_etal_2020_changepoints}{funtimes}.
 #' 
 #' @details The sieve bootstrap is applied by approximating regression residuals \code{e} 
 #' with an AR(\eqn{p}) model using function \code{\link{ARest}}, 
@@ -12,7 +12,8 @@
 #' (see \code{\link{ARest}}). At the next step, \code{B} autoregressive processes 
 #' are simulated under the null hypothesis of no change points.
 #' The distribution of test statistics \eqn{M_T} computed on each of those 
-#' bootstrapped series is used to obtain bootstrap-based \eqn{p}-values for the test. 
+#' bootstrapped series is used to obtain bootstrap-based \eqn{p}-values for the test 
+#' \insertCite{Lyubchich_etal_2020_changepoints}{funtimes}. 
 #' 
 #' The test statistic corresponds to the maximal value of the modified CUSUM over
 #' all combinations of hypothesized change points specified in \code{k}. The change 
@@ -55,7 +56,12 @@
 #' @references
 #' \insertAllCited{}
 #' 
-#' @keywords changepoint htest ts
+#' @keywords internal
+NULL
+
+#' @rdname funtimes-deprecated
+#' @section \code{mcusum.test}:
+#' For \code{mcusum.test}, use \code{\link{mcusum_test}}.
 #' 
 #' @author Vyacheslav Lyubchich
 #' 
@@ -68,7 +74,7 @@
 #' SizeOfChange <- 1
 #' TimeOfChange <- 50
 #' Y <- c(1 * X[1:TimeOfChange] + E[1:TimeOfChange], 
-#'       (1 + SizeOfChange)*X[(TimeOfChange+1):T] + E[(TimeOfChange+1):T])
+#'       (1 + SizeOfChange)*X[(TimeOfChange + 1):T] + E[(TimeOfChange + 1):T])
 #' ehat <- lm(Y ~ X)$resid
 #' mcusum.test(ehat, k = c(30, 50, 70))
 #' 
@@ -78,12 +84,13 @@
 mcusum.test <- function(e, k, B = 1000, ksm = FALSE, 
                         ksm.arg = list(kernel = "gaussian", bw = "sj"), ...)
 {
+    .Deprecated("mcusum_test", msg = "mcusum.test is deprecated and will be removed. Use mcusum_test instead.")
     DNAME <- deparse(substitute(e))
     T <- length(e)
     e <- e - mean(e)
     phi <- ARest(e, ...)
     MTobs <- MTfun(e, k = k)
-    if(length(phi) > 0) {
+    if (length(phi) > 0) {
         e <-  as.vector(embed(e, length(phi) + 1L) %*% c(1, -phi))
         e <- e - mean(e)
     }
@@ -96,7 +103,7 @@ mcusum.test <- function(e, k, B = 1000, ksm = FALSE,
                             innov = rnorm(T, mean = sample(e, size = T, replace = TRUE), sd = bw)), 
                   k = k)$MT
         )
-    } else { #use bootstrapped e
+    } else {#use bootstrapped e
         MTboot <- sapply(1:B, function(b) 
             MTfun(arima.sim(T, model = list(order = c(length(phi), 0, 0), ar = phi), 
                             innov = sample(e, size = T, replace = TRUE)), k = k)$MT
