@@ -22,7 +22,7 @@
 #' (time series in columns) which is passed to \code{\link{sync.test}}. 
 #' Variable \eqn{t} should be used to specify the form 
 #' of the trend, where \eqn{t} is specified within the function automatically as a 
-#' regular sequence of length \eqn{T} on the interval (0,1]. See `Examples'.
+#' regular sequence of length \eqn{T} on the interval (0,1]. See \code{Examples}.
 #' @param rate rate of removal of time series. Default is 1 (i.e., if hypothesis 
 #' of synchronism is rejected one time series is removed at a time to re-test the 
 #' remaining time series). Integer values above 1 are treated as number of time 
@@ -67,7 +67,12 @@
 #' 
 #' @seealso \code{\link{BICC}}, \code{\link{DR}}, \code{\link{sync.test}}
 #' 
-#' @keywords cluster trend synchrony
+#' @keywords internal
+NULL
+
+#' @rdname funtimes-deprecated
+#' @section \code{sync.cluster}:
+#' For \code{sync.cluster}, use \code{\link{sync_cluster}}.
 #' 
 #' @author Srishti Vishwakarma, Vyacheslav Lyubchich
 #' 
@@ -122,6 +127,7 @@
 #' 
 sync.cluster <- function(formula, rate = 1, alpha = 0.05, ...) 
 {
+    .Deprecated("sync_cluster", msg = "sync.cluster is deprecated and will be removed. Use sync_cluster instead.")
     ## separating formula to find the time series
     frml <- deparse(substitute(formula))
     splt <- strsplit(frml, "~")[[1]]
@@ -167,7 +173,7 @@ sync.cluster <- function(formula, rate = 1, alpha = 0.05, ...)
             sync.all_considered_windows[[K]] = SyncResults$estimate$all_considered_windows
             sync.wavk_obs[[K]] = SyncResults$estimate$wavk_obs
             K = K + 1
-        } else { #the H0 of trend synchronism is rejected
+        } else {#the H0 of trend synchronism is rejected
             # Extracting local factor statistics
             WAVKResults <- abs(SyncResults$estimate$wavk_obs)
             # Sorting the WAVK result
@@ -179,7 +185,7 @@ sync.cluster <- function(formula, rate = 1, alpha = 0.05, ...)
             }
             # Make sure at least 1 time series should be removed, but less than 
             # the number of time series remaining in Ystar
-            if (nRM >= ncol(Ystar) || nRM == 0){
+            if (nRM >= ncol(Ystar) || nRM == 0) {
                 nRM <- 1 
             }
             # Removing the time series as per the rate
