@@ -10,7 +10,7 @@
 #' @param formula an object of class "\code{\link[stats]{formula}}", specifying the 
 #' form of the parametric time trend to be tested. Variable \eqn{t} should be used 
 #' to specify the form, where \eqn{t} is specified within the function as a regular 
-#' sequence on the interval (0,1]. See `Examples'.
+#' sequence on the interval (0,1]. See \code{Examples}.
 #' @param factor.length method to define the length of local windows (factors). 
 #' Default option\cr \code{"user.defined"} allows to set only one value of the argument 
 #' \code{Window}. The option \code{"adaptive.selection"} sets \code{method = "boot"} 
@@ -55,7 +55,12 @@
 #' @seealso \code{\link[stats]{ar}}, \code{\link{HVK}}, \code{\link{WAVK}}, 
 #' \code{\link{sync.test}}
 #' 
-#' @keywords htest ts trend
+#' @keywords internal
+NULL
+
+#' @rdname funtimes-deprecated
+#' @section \code{wavk.test}:
+#' For \code{wavk.test}, use \code{\link{wavk_test}}.
 #' 
 #' @author Yulia R. Gel, Vyacheslav Lyubchich, Ethan Schaeffer
 #' 
@@ -123,11 +128,13 @@ wavk.test <- function(formula, factor.length = c("user.defined", "adaptive.selec
                       Window = NULL, q = 3/4, j = c(8:11), B = 1000, method = c("boot", "asympt"), 
                       ar.order = NULL, ar.method = "HVK", BIC = TRUE, out = FALSE)
 {
+    .Deprecated("wavk.test", msg = "wavk.test is deprecated and will be removed. Use wavk_test instead.")
     ### Perform various checks.
     frml <- deparse(substitute(formula))
     splt <- strsplit(frml, "~")[[1]]
     DNAME <- splt[1]
-    x <- eval(parse(text = DNAME))
+    x <- lm(formula = as.formula(paste0(DNAME, "~ 1"), env = parent.frame(n = 4)), 
+            method = "model.frame")[,1]
     if (is.null(Window)) {
         Window = round(0.1*length(x))
     }
@@ -182,24 +189,24 @@ wavk.test <- function(formula, factor.length = c("user.defined", "adaptive.selec
     if (is.null(ar.order)) {
         ar.order <- floor(10*log10(n))
     }
-    mod <- lm(as.formula(frml))
+    mod <- lm(as.formula(as.formula(paste0("x ~ ", splt[2]))))
     TrendCoeff <- mod$coefficients
     TS <- as.vector(mod$residuals)
-    ALTERNATIVE <- paste("trend is not of the form ", frml, ".", sep="")
-    pheta <- ARest(TS, ar.order=ar.order, ar.method=ar.method, BIC=BIC)
-    if (length(pheta)>0) {
-        names(pheta) <- paste(rep("phi_", length(pheta)), c(1:length(pheta)), sep="")
-        tmp <- filter(x, pheta, sides=1)
-        tmp2 <- filter(mod$fitted.values, pheta, sides=1)
-        Z <- (x[(length(pheta)+1):n] - tmp[length(pheta):(n-1)]) - 
-            (mod$fitted.values[(length(pheta)+1):n] - tmp2[length(pheta):(n-1)])
+    ALTERNATIVE <- paste("trend is not of the form ", frml, ".", sep = "")
+    pheta <- ARest(TS, ar.order = ar.order, ar.method = ar.method, BIC = BIC)
+    if (length(pheta) > 0) {
+        names(pheta) <- paste(rep("phi_", length(pheta)), c(1:length(pheta)), sep = "")
+        tmp <- filter(x, pheta, sides = 1)
+        tmp2 <- filter(mod$fitted.values, pheta, sides = 1)
+        Z <- (x[(length(pheta) + 1):n] - tmp[length(pheta):(n - 1)]) - 
+            (mod$fitted.values[(length(pheta) + 1):n] - tmp2[length(pheta):(n - 1)])
     } else {
         Z <- TS
     }
     ESTIMATE <- list(TrendCoeff, length(pheta), pheta)
     names(ESTIMATE) <- c("trend_coefficients", "AR_order", "AR_coefficients")
     Z <- Z - mean(Z)
-    sigma <- sqrt(sum(diff(Z)^2)/(2*(length(Z)-1)))
+    sigma <- sqrt(sum(diff(Z)^2)/(2*(length(Z) - 1)))
     if (method == "asympt") {
         METHOD <- "Trend test by Wang, Akritas, and Van Keilegom (asymptotic p-values)"
         for (i in 1:length(kn)) {
@@ -212,16 +219,16 @@ wavk.test <- function(formula, factor.length = c("user.defined", "adaptive.selec
         names(PARAMETER) <- "user-defined window"
     } else {
         METHOD <- "Trend test by Wang, Akritas, and Van Keilegom (bootstrap p-values)"
-        boot <- array(data=rnorm(n*B), c(n,B)) * sigma
-        s <- array(data=NA, c(length(kn), B))
+        boot <- array(data = rnorm(n*B), c(n,B)) * sigma
+        s <- array(data = NA, c(length(kn), B))
         for (i in 1:length(kn)) {
             s[i,] <- apply(boot, 2, function(x) WAVK(x, kn[i])$Tns)
-            result[i,1] <- WAVK(Z, kn[i])$Tns
+            result[i, 1] <- WAVK(Z, kn[i])$Tns
             crit <- sum(result[i,1] < s[i,])/B
             if (crit < 0.5) {
-                result[i,2] <- 2*crit
+                result[i, 2] <- 2*crit
             } else {
-                result[i,2] <- 2*(1-crit)
+                result[i, 2] <- 2*(1 - crit)
             }
         }
         if (length(kn) < 3) {
@@ -231,7 +238,7 @@ wavk.test <- function(formula, factor.length = c("user.defined", "adaptive.selec
             names(PARAMETER) <- "user-defined window"
         } else {
             s <- t(apply(s, 1, sort))
-            distance <- sapply(1:(length(kn)-1), function(x) dist(s[x:(x+1),]))
+            distance <- sapply(1:(length(kn) - 1), function(x) dist(s[x:(x + 1),]))
             kn_opt <- kn[which.min(distance)]
             res[1,] <- result[which.min(distance),]
             STATISTIC <- res[1,1]
